@@ -17,7 +17,7 @@ from artify import initialize
 from artify import archive
 from artify import changelog
 
-debug = 0;
+debug = 0
 
 from requests.packages.urllib3.exceptions import InsecureRequestWarning
 
@@ -191,6 +191,14 @@ def main(argv):
                 print("\n--proxy             Sets Http proxy")
                 print("--proxysec          Sets Https proxy")
                 return sys.exit(0)
+            elif arg == "changelog":
+                print('')
+                print("How to generate CHANGELOG.md file")
+                print("")
+                print("Usage: python -m artify -c changelog <optional_parameter>\n")
+                print("Optional argument(s): ")
+                print("\n--projectname      Used to specify project when solution has more than 1 project. For .NET/NET core projects")
+                return sys.exit(0)
             elif arg == "syncrepo":
                 print('')
                 print("How to Push and Commit changes\n")
@@ -199,6 +207,7 @@ def main(argv):
                 print("-m, --message     Commit message")
                 print("\nOptional arguments: ")
                 #print("-h, --host        Repository url")
+                print("--projectname   Used to specify project when solution has more than 1 project .NET/Netcore projects")
                 print("-b, --branch     Repository branch to sync changes")
                 print("\n--proxy             Sets Http proxy")
                 print("--proxysec          Sets Https proxy")
@@ -405,6 +414,16 @@ def main(argv):
                 if archive_basename == '':
                     print('Please specify archive name e.g myfile')
                     return sys.exit(2)
+            elif action == 'syncrepo':
+                project_name = arg
+                if project_name == '':
+                    print("Please specify project name")
+                    return sys.exit(2)
+            elif action == 'changelog':
+                project_name = arg
+                if project_name == '':
+                    print("Please specify project name")
+                    return sys.exit(2)
             else:
                 artifact_name = arg
                 if artifact_name == '':
