@@ -61,17 +61,17 @@ def get_version(filename, vtype):
                     result = 0
                     versionstr = line
                     break                    
-                if __main__.arch_type == 'netcore' and re.search(r'<AssemblyVersion>', line):
+                if __main__.arch_type == 'netcore' and (re.search(r'<AssemblyVersion>', line) or re.search(r'<Version>', line)):
                     result = 0
                     versionstr = line
                     break  
-                if vtype == 'custom' and re.search(r"\d*\.\d*\.\d*[.\d]*[-]*[+]*[0-9A-Za-z]*[.]*[0-9a-zA-Z]*[+]*[0-9a-zA-Z]*", line):
+                if vtype == 'custom' and re.search(r"\d{1,}\.\d*\.\d*[.\d]*[-]*[+]*[0-9A-Za-z]*[.]*[0-9a-zA-Z]*[+]*[0-9a-zA-Z]*", line):
                     result = 0
                     versionstr = line
                     break                 
 
     else:
-        print("INFO: Could not find file with version number")
+        print("INFO: Could not find file with version number. File path: "+ filename)
         return __main__.sys.exit(2)
     
     if __main__.debug == 1:
@@ -134,7 +134,7 @@ def get_version(filename, vtype):
 
     if vtype == 'custom':
         strip_version = versionstr.strip()
-        version_string_tmp = re.search(r"\d*\.\d*\.\d*[.\d]*[-]*[+]*[0-9A-Za-z]*[.]*[0-9a-zA-Z]*[+]*[0-9a-zA-Z]*", strip_version)
+        version_string_tmp = re.search(r"\d{1,}\.\d*\.\d*[.\d]*[-]*[+]*[0-9A-Za-z]*[.]*[0-9a-zA-Z]*[+]*[0-9a-zA-Z]*", strip_version)
         if (__main__.debug == 1):
             print("DEBUG: Version String: Custom: ", version_string_tmp)
         if version_string_tmp:
@@ -248,20 +248,22 @@ def process_version(versionstr):
         build = int(build) + 1    
         
     if __main__.change_type == "auto":
-
-        if prelease_version != '':
-            current_pre_build = re.sub("\D", "", prelease_version)
-            if current_pre_build != '':
-                new_prebuild = int(current_pre_build) + 1
-                current_pre_string = re.sub("\s*", "", prelease_version)
-                if current_pre_string != '':
-                    prelease_version = prelease_version.replace(str(current_pre_build), str(new_prebuild))
+        if __main__.arch_type == 'netcore' or __main__.arch_type == 'dotnet':
+            build = int(build) + 1
+        else:
+            if prelease_version != '':
+                current_pre_build = re.sub("\D", "", prelease_version)
+                if current_pre_build != '':
+                    new_prebuild = int(current_pre_build) + 1
+                    current_pre_string = re.sub("\s*", "", prelease_version)
+                    if current_pre_string != '':
+                        prelease_version = prelease_version.replace(str(current_pre_build), str(new_prebuild))
+                    else:
+                        prelease_version = 'build.' + new_prebuild
                 else:
-                    prelease_version = 'build.' + new_prebuild
+                    prelease_version = 'build.1'
             else:
                 prelease_version = 'build.1'
-        else:
-            prelease_version = 'build.1'
             
         if __main__.debug == 1:
             print("DEBUG: Updated: Prerelease value: ", prelease_version)
@@ -365,8 +367,8 @@ def change_version_file(filepath, version, newversion):
         replace_version(filepath, old_version, new_version)        
     
     if __main__.arch_type == 'netcore':
-        old_version = "<AssemblyVersion>{}</AssemblyVersion>".format(version)
-        new_version = "<AssemblyVersion>{}</AssemblyVersion>".format(newversion)
+        old_version = "<Version>{}</Version>".format(version)
+        new_version = "<Version>{}</Version>".format(newversion)
         replace_version(filepath, old_version, new_version)      
          
 def change_manifest(v, dv):
@@ -447,7 +449,21 @@ def modify_version():
         version_file = __main__.version_file1
     
     if __main__.arch_type == 'netcore':
-        version_file = __main__.version_file1
+        if __main__.version_file1:
+            version_file = __main__.version_file1
+        else:
+            file_list = glob('*.sln') 
+            if len(file_list) >= 1:
+                filename, filextension = __main__.os.path.splitext(file_list[0])
+                version_file = __main__.os.path.join(filename, filename, filename + '.csproj') 
+            else:
+                proj_file = glob('*.csproj')
+                if len(proj_file) >= 1:
+                    filename, filextension = __main__.os.path.splitext(proj_file[0])
+                    version_file = __main__.os.path.join(filename+filextension)
+                else:
+                    print("ERROR: Could not find project file")
+                    return __main__.sys.exit(2)
    
     
     filepath = __main__.os.path.join(path, version_file)
