@@ -4,6 +4,7 @@ from artify import change_version
 
 def commit_push_changes(message):
     print("INFO: Committing changes")
+    projfile = ''
     
     version = None
     
@@ -50,6 +51,44 @@ def commit_push_changes(message):
             __main__.arch_type = 'maven'
             filepath = __main__.os.path.join(path,'pom.xml')
             version = change_version.get_version(filepath, 'standard')
+       
+   
+        file_list = change_version.glob('*.sln')
+        if (len(file_list)) == 1: #-solution_name
+            __main__.arch_type = 'dotnet'
+            if (__main__.debug == 1):
+                print("DEBUG: Solution file found:: ",file_list)
+            flnme, extn = file_list[0].split('.')
+            #project name
+            if __main__.project_name != '':
+                projfile = [__main__.os.path.join(__main__.project_name,__main__.project_name+'.csproj')]
+            else:
+                projfile = change_version.glob(__main__.os.path.join(flnme,'*.csproj'))
+            
+            if __main__.debug == 1:
+                print("DEBUG: Project file found:: ", projfile)
+
+            if len(projfile) == 1:
+                filepath = __main__.os.path.join(path, projfile[0])
+                version = change_version.get_version(filepath, 'custom')
+                
+        file_list_proj = change_version.glob('*.csproj')
+        if (len(file_list_proj)) == 1: #-project_name
+            __main__.arch_type = 'dotnet'
+            if (__main__.debug == 1):
+                print("DEBUG: Project file found:: ",file_list_proj)
+           
+            if __main__.project_name != '':
+                projfile = [__main__.project_name + '.csproj']
+            else:
+                projfile = file_list_proj
+
+            if len(projfile) == 1:
+                filepath = __main__.os.path.join(path, projfile[0])
+                version = change_version.get_version(filepath, 'custom')
+        
+        #if __main__.os.path.exists(__main__.os.path.join(path, '*.csproj')):
+        #    __main__.arch_type = 'dotnetcore'
 
         if __main__.os.path.exists(__main__.os.path.join(path,'pubspec.yaml')):
             __main__.arch_type = 'flutter'
